==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "New text file" : "New text file",
    "File not found" : "File not found",
    "Text" : "Text",
    "Translate" : "Translate",
    "Delete task" : "Delete task",
    "Reload" : "Reload",
    "Guest" : "Guest",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Quoted text" : "Quoted text",
    "Link" : "Link",
    "Smart picker" : "Smart picker",
    "Action" : "Action",
    "Undo" : "Undo",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Formatting help" : "Formatting help",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Edit" : "Edit",
    "Copy code block" : "Copy code block",
    "Source code" : "Source code",
    "Done" : "Done",
    "Headings" : "Headings",
    "Lists" : "Lists",
    "Details" : "Details",
    "Command" : "Command",
    "Ctrl" : "Ctrl",
    "Formatting" : "Formatting",
    "Info" : "Info",
    "Warning" : "Warning"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "New text file" : "New text file",
    "File not found" : "File not found",
    "Text" : "Text",
    "Reload" : "Reload",
    "Enter your name" : "Enter your name",
    "Guest" : "Guest",
    "Copy link" : "Copy link",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Quoted text" : "Quoted text",
    "Link" : "Link",
    "Smart picker" : "Smart picker",
    "Action" : "Action",
    "Undo" : "Undo",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Save" : "დამახსოვრება",
    "Formatting help" : "Formatting help",
    "Translate" : "Translate",
    "Nextcloud Assistant" : "Nextcloud-ის ასისტენტი",
    "Delete task" : "Delete task",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Upload" : "Upload",
    "Edit" : "Edit",
    "Copy code block" : "Copy code block",
    "Source code" : "Source code",
    "Done" : "Done",
    "Headings" : "Headings",
    "Lists" : "Lists",
    "Details" : "Details",
    "Command" : "Command",
    "Ctrl" : "Ctrl",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Choose" : "Choose",
    "Choose {file}" : "Choose {file}",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually"
},
"nplurals=2; plural=(n!=1);");
